import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:sign_in_with_apple/sign_in_with_apple.dart';

class SocialLoginHandler {
  static Future<AppResponse<GoogleAuthCredential>> signInWithGoogle() async {
    try {
      GoogleSignIn _googleSign = GoogleSignIn();
      await _googleSign.signOut();
      var response = await _googleSign.signIn();
      var authentication = await response.authentication;
      var credential = GoogleAuthProvider.credential(
          accessToken: authentication.accessToken,
          idToken: authentication.idToken);
      return AppResponse.named(data: credential);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "Some error occurred");
    }
  }

  static Future<AppResponse<FacebookAuthCredential>> signInWithFacebook(
      List<String> scopes) async {
    try {
      FacebookLogin _facebookLogin = FacebookLogin();
      await _facebookLogin.logOut();
      var authentication = await _facebookLogin.logIn(scopes);
      switch (authentication.status) {
        case FacebookLoginStatus.cancelledByUser:
          return AppResponse.named(error: "Cancelled by user");
          break;
        case FacebookLoginStatus.loggedIn:
          AuthCredential credential = FacebookAuthProvider.credential(
            authentication.accessToken.token,
          );
          return AppResponse.named(data: credential);
          break;
        default:
          return AppResponse.named(error: "Some error occurred");
      }
    } catch (e) {
      return AppResponse.named(error: "$e");
    }
  }

  static Future<AppResponse<OAuthCredential>> signInWithApple() async {
    try {
      final credential = await SignInWithApple.getAppleIDCredential(
        scopes: [
          AppleIDAuthorizationScopes.email,
          AppleIDAuthorizationScopes.fullName,
        ],
      );
      debugPrint("${credential.email}");
      final oAuthProvider = OAuthProvider('apple.com');
      final oCredential = oAuthProvider.credential(
        idToken: credential.identityToken,
        accessToken: credential.authorizationCode,
      );
      return AppResponse.named(data: oCredential);
    } catch (e) {
      return AppResponse.named(error: "$e");
    }
  }
}
